Method: Statsd#timing
- Defined in:
- lib/statsd.rb
#timing(stat, ms, sample_rate = 1) ⇒ Object
Sends a timing (in ms) for the given stat to the statsd server. The sample_rate determines what percentage of the time this report is sent. The statsd server then uses the sample_rate to correctly track the average timing for the stat.
412 413 414 |
# File 'lib/statsd.rb', line 412 def timing(stat, ms, sample_rate=1) send_stats stat, ms, :ms, sample_rate end |